# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.summary_athlete import SummaryAthlete  # noqa: F401,E501
from swagger_client.models.summary_club import SummaryClub  # noqa: F401,E501
from swagger_client.models.summary_gear import SummaryGear  # noqa: F401,E501


class DetailedAthlete(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'resource_state': 'int',
        'firstname': 'str',
        'lastname': 'str',
        'profile_medium': 'str',
        'profile': 'str',
        'city': 'str',
        'state': 'str',
        'country': 'str',
        'sex': 'str',
        'friend': 'str',
        'follower': 'str',
        'premium': 'bool',
        'summit': 'bool',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'follower_count': 'int',
        'friend_count': 'int',
        'mutual_friend_count': 'int',
        'measurement_preference': 'str',
        'ftp': 'int',
        'weight': 'float',
        'clubs': 'list[SummaryClub]',
        'bikes': 'list[SummaryGear]',
        'shoes': 'list[SummaryGear]'
    }

    attribute_map = {
        'id': 'id',
        'resource_state': 'resource_state',
        'firstname': 'firstname',
        'lastname': 'lastname',
        'profile_medium': 'profile_medium',
        'profile': 'profile',
        'city': 'city',
        'state': 'state',
        'country': 'country',
        'sex': 'sex',
        'friend': 'friend',
        'follower': 'follower',
        'premium': 'premium',
        'summit': 'summit',
        'created_at': 'created_at',
        'updated_at': 'updated_at',
        'follower_count': 'follower_count',
        'friend_count': 'friend_count',
        'mutual_friend_count': 'mutual_friend_count',
        'measurement_preference': 'measurement_preference',
        'ftp': 'ftp',
        'weight': 'weight',
        'clubs': 'clubs',
        'bikes': 'bikes',
        'shoes': 'shoes'
    }

    def __init__(self, id=None, resource_state=None, firstname=None, lastname=None, profile_medium=None, profile=None, city=None, state=None, country=None, sex=None, friend=None, follower=None, premium=None, summit=None, created_at=None, updated_at=None, follower_count=None, friend_count=None, mutual_friend_count=None, measurement_preference=None, ftp=None, weight=None, clubs=None, bikes=None, shoes=None):  # noqa: E501
        """DetailedAthlete - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._resource_state = None
        self._firstname = None
        self._lastname = None
        self._profile_medium = None
        self._profile = None
        self._city = None
        self._state = None
        self._country = None
        self._sex = None
        self._friend = None
        self._follower = None
        self._premium = None
        self._summit = None
        self._created_at = None
        self._updated_at = None
        self._follower_count = None
        self._friend_count = None
        self._mutual_friend_count = None
        self._measurement_preference = None
        self._ftp = None
        self._weight = None
        self._clubs = None
        self._bikes = None
        self._shoes = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if resource_state is not None:
            self.resource_state = resource_state
        if firstname is not None:
            self.firstname = firstname
        if lastname is not None:
            self.lastname = lastname
        if profile_medium is not None:
            self.profile_medium = profile_medium
        if profile is not None:
            self.profile = profile
        if city is not None:
            self.city = city
        if state is not None:
            self.state = state
        if country is not None:
            self.country = country
        if sex is not None:
            self.sex = sex
        if friend is not None:
            self.friend = friend
        if follower is not None:
            self.follower = follower
        if premium is not None:
            self.premium = premium
        if summit is not None:
            self.summit = summit
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if follower_count is not None:
            self.follower_count = follower_count
        if friend_count is not None:
            self.friend_count = friend_count
        if mutual_friend_count is not None:
            self.mutual_friend_count = mutual_friend_count
        if measurement_preference is not None:
            self.measurement_preference = measurement_preference
        if ftp is not None:
            self.ftp = ftp
        if weight is not None:
            self.weight = weight
        if clubs is not None:
            self.clubs = clubs
        if bikes is not None:
            self.bikes = bikes
        if shoes is not None:
            self.shoes = shoes

    @property
    def id(self):
        """Gets the id of this DetailedAthlete.  # noqa: E501

        The unique identifier of the athlete  # noqa: E501

        :return: The id of this DetailedAthlete.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DetailedAthlete.

        The unique identifier of the athlete  # noqa: E501

        :param id: The id of this DetailedAthlete.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def resource_state(self):
        """Gets the resource_state of this DetailedAthlete.  # noqa: E501

        Resource state, indicates level of detail. Possible values: 1 -> \"meta\", 2 -> \"summary\", 3 -> \"detail\"  # noqa: E501

        :return: The resource_state of this DetailedAthlete.  # noqa: E501
        :rtype: int
        """
        return self._resource_state

    @resource_state.setter
    def resource_state(self, resource_state):
        """Sets the resource_state of this DetailedAthlete.

        Resource state, indicates level of detail. Possible values: 1 -> \"meta\", 2 -> \"summary\", 3 -> \"detail\"  # noqa: E501

        :param resource_state: The resource_state of this DetailedAthlete.  # noqa: E501
        :type: int
        """

        self._resource_state = resource_state

    @property
    def firstname(self):
        """Gets the firstname of this DetailedAthlete.  # noqa: E501

        The athlete's first name.  # noqa: E501

        :return: The firstname of this DetailedAthlete.  # noqa: E501
        :rtype: str
        """
        return self._firstname

    @firstname.setter
    def firstname(self, firstname):
        """Sets the firstname of this DetailedAthlete.

        The athlete's first name.  # noqa: E501

        :param firstname: The firstname of this DetailedAthlete.  # noqa: E501
        :type: str
        """

        self._firstname = firstname

    @property
    def lastname(self):
        """Gets the lastname of this DetailedAthlete.  # noqa: E501

        The athlete's last name.  # noqa: E501

        :return: The lastname of this DetailedAthlete.  # noqa: E501
        :rtype: str
        """
        return self._lastname

    @lastname.setter
    def lastname(self, lastname):
        """Sets the lastname of this DetailedAthlete.

        The athlete's last name.  # noqa: E501

        :param lastname: The lastname of this DetailedAthlete.  # noqa: E501
        :type: str
        """

        self._lastname = lastname

    @property
    def profile_medium(self):
        """Gets the profile_medium of this DetailedAthlete.  # noqa: E501

        URL to a 62x62 pixel profile picture.  # noqa: E501

        :return: The profile_medium of this DetailedAthlete.  # noqa: E501
        :rtype: str
        """
        return self._profile_medium

    @profile_medium.setter
    def profile_medium(self, profile_medium):
        """Sets the profile_medium of this DetailedAthlete.

        URL to a 62x62 pixel profile picture.  # noqa: E501

        :param profile_medium: The profile_medium of this DetailedAthlete.  # noqa: E501
        :type: str
        """

        self._profile_medium = profile_medium

    @property
    def profile(self):
        """Gets the profile of this DetailedAthlete.  # noqa: E501

        URL to a 124x124 pixel profile picture.  # noqa: E501

        :return: The profile of this DetailedAthlete.  # noqa: E501
        :rtype: str
        """
        return self._profile

    @profile.setter
    def profile(self, profile):
        """Sets the profile of this DetailedAthlete.

        URL to a 124x124 pixel profile picture.  # noqa: E501

        :param profile: The profile of this DetailedAthlete.  # noqa: E501
        :type: str
        """

        self._profile = profile

    @property
    def city(self):
        """Gets the city of this DetailedAthlete.  # noqa: E501

        The athlete's city.  # noqa: E501

        :return: The city of this DetailedAthlete.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this DetailedAthlete.

        The athlete's city.  # noqa: E501

        :param city: The city of this DetailedAthlete.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state(self):
        """Gets the state of this DetailedAthlete.  # noqa: E501

        The athlete's state or geographical region.  # noqa: E501

        :return: The state of this DetailedAthlete.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this DetailedAthlete.

        The athlete's state or geographical region.  # noqa: E501

        :param state: The state of this DetailedAthlete.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def country(self):
        """Gets the country of this DetailedAthlete.  # noqa: E501

        The athlete's country.  # noqa: E501

        :return: The country of this DetailedAthlete.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this DetailedAthlete.

        The athlete's country.  # noqa: E501

        :param country: The country of this DetailedAthlete.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def sex(self):
        """Gets the sex of this DetailedAthlete.  # noqa: E501

        The athlete's sex.  # noqa: E501

        :return: The sex of this DetailedAthlete.  # noqa: E501
        :rtype: str
        """
        return self._sex

    @sex.setter
    def sex(self, sex):
        """Sets the sex of this DetailedAthlete.

        The athlete's sex.  # noqa: E501

        :param sex: The sex of this DetailedAthlete.  # noqa: E501
        :type: str
        """
        allowed_values = ["M", "F"]  # noqa: E501
        if sex not in allowed_values:
            raise ValueError(
                "Invalid value for `sex` ({0}), must be one of {1}"  # noqa: E501
                .format(sex, allowed_values)
            )

        self._sex = sex

    @property
    def friend(self):
        """Gets the friend of this DetailedAthlete.  # noqa: E501

        Whether the currently logged-in athlete follows this athlete.  # noqa: E501

        :return: The friend of this DetailedAthlete.  # noqa: E501
        :rtype: str
        """
        return self._friend

    @friend.setter
    def friend(self, friend):
        """Sets the friend of this DetailedAthlete.

        Whether the currently logged-in athlete follows this athlete.  # noqa: E501

        :param friend: The friend of this DetailedAthlete.  # noqa: E501
        :type: str
        """
        allowed_values = ["pending", "accepted", "blocked"]  # noqa: E501
        if friend not in allowed_values:
            raise ValueError(
                "Invalid value for `friend` ({0}), must be one of {1}"  # noqa: E501
                .format(friend, allowed_values)
            )

        self._friend = friend

    @property
    def follower(self):
        """Gets the follower of this DetailedAthlete.  # noqa: E501

        Whether this athlete follows the currently logged-in athlete.  # noqa: E501

        :return: The follower of this DetailedAthlete.  # noqa: E501
        :rtype: str
        """
        return self._follower

    @follower.setter
    def follower(self, follower):
        """Sets the follower of this DetailedAthlete.

        Whether this athlete follows the currently logged-in athlete.  # noqa: E501

        :param follower: The follower of this DetailedAthlete.  # noqa: E501
        :type: str
        """
        allowed_values = ["pending", "accepted", "blocked"]  # noqa: E501
        if follower not in allowed_values:
            raise ValueError(
                "Invalid value for `follower` ({0}), must be one of {1}"  # noqa: E501
                .format(follower, allowed_values)
            )

        self._follower = follower

    @property
    def premium(self):
        """Gets the premium of this DetailedAthlete.  # noqa: E501

        Deprecated.  Use summit field instead. Whether the athlete has any Summit subscription.  # noqa: E501

        :return: The premium of this DetailedAthlete.  # noqa: E501
        :rtype: bool
        """
        return self._premium

    @premium.setter
    def premium(self, premium):
        """Sets the premium of this DetailedAthlete.

        Deprecated.  Use summit field instead. Whether the athlete has any Summit subscription.  # noqa: E501

        :param premium: The premium of this DetailedAthlete.  # noqa: E501
        :type: bool
        """

        self._premium = premium

    @property
    def summit(self):
        """Gets the summit of this DetailedAthlete.  # noqa: E501

        Whether the athlete has any Summit subscription.  # noqa: E501

        :return: The summit of this DetailedAthlete.  # noqa: E501
        :rtype: bool
        """
        return self._summit

    @summit.setter
    def summit(self, summit):
        """Sets the summit of this DetailedAthlete.

        Whether the athlete has any Summit subscription.  # noqa: E501

        :param summit: The summit of this DetailedAthlete.  # noqa: E501
        :type: bool
        """

        self._summit = summit

    @property
    def created_at(self):
        """Gets the created_at of this DetailedAthlete.  # noqa: E501

        The time at which the athlete was created.  # noqa: E501

        :return: The created_at of this DetailedAthlete.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this DetailedAthlete.

        The time at which the athlete was created.  # noqa: E501

        :param created_at: The created_at of this DetailedAthlete.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this DetailedAthlete.  # noqa: E501

        The time at which the athlete was last updated.  # noqa: E501

        :return: The updated_at of this DetailedAthlete.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this DetailedAthlete.

        The time at which the athlete was last updated.  # noqa: E501

        :param updated_at: The updated_at of this DetailedAthlete.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def follower_count(self):
        """Gets the follower_count of this DetailedAthlete.  # noqa: E501

        The athlete's follower count.  # noqa: E501

        :return: The follower_count of this DetailedAthlete.  # noqa: E501
        :rtype: int
        """
        return self._follower_count

    @follower_count.setter
    def follower_count(self, follower_count):
        """Sets the follower_count of this DetailedAthlete.

        The athlete's follower count.  # noqa: E501

        :param follower_count: The follower_count of this DetailedAthlete.  # noqa: E501
        :type: int
        """

        self._follower_count = follower_count

    @property
    def friend_count(self):
        """Gets the friend_count of this DetailedAthlete.  # noqa: E501

        The athlete's friend count.  # noqa: E501

        :return: The friend_count of this DetailedAthlete.  # noqa: E501
        :rtype: int
        """
        return self._friend_count

    @friend_count.setter
    def friend_count(self, friend_count):
        """Sets the friend_count of this DetailedAthlete.

        The athlete's friend count.  # noqa: E501

        :param friend_count: The friend_count of this DetailedAthlete.  # noqa: E501
        :type: int
        """

        self._friend_count = friend_count

    @property
    def mutual_friend_count(self):
        """Gets the mutual_friend_count of this DetailedAthlete.  # noqa: E501

        The number or athletes mutually followed by this athlete and the currently logged-in athlete.  # noqa: E501

        :return: The mutual_friend_count of this DetailedAthlete.  # noqa: E501
        :rtype: int
        """
        return self._mutual_friend_count

    @mutual_friend_count.setter
    def mutual_friend_count(self, mutual_friend_count):
        """Sets the mutual_friend_count of this DetailedAthlete.

        The number or athletes mutually followed by this athlete and the currently logged-in athlete.  # noqa: E501

        :param mutual_friend_count: The mutual_friend_count of this DetailedAthlete.  # noqa: E501
        :type: int
        """

        self._mutual_friend_count = mutual_friend_count

    @property
    def measurement_preference(self):
        """Gets the measurement_preference of this DetailedAthlete.  # noqa: E501

        The athlete's preferred unit system.  # noqa: E501

        :return: The measurement_preference of this DetailedAthlete.  # noqa: E501
        :rtype: str
        """
        return self._measurement_preference

    @measurement_preference.setter
    def measurement_preference(self, measurement_preference):
        """Sets the measurement_preference of this DetailedAthlete.

        The athlete's preferred unit system.  # noqa: E501

        :param measurement_preference: The measurement_preference of this DetailedAthlete.  # noqa: E501
        :type: str
        """
        allowed_values = ["feet", "meters"]  # noqa: E501
        if measurement_preference not in allowed_values:
            raise ValueError(
                "Invalid value for `measurement_preference` ({0}), must be one of {1}"  # noqa: E501
                .format(measurement_preference, allowed_values)
            )

        self._measurement_preference = measurement_preference

    @property
    def ftp(self):
        """Gets the ftp of this DetailedAthlete.  # noqa: E501

        The athlete's FTP (Functional Threshold Power).  # noqa: E501

        :return: The ftp of this DetailedAthlete.  # noqa: E501
        :rtype: int
        """
        return self._ftp

    @ftp.setter
    def ftp(self, ftp):
        """Sets the ftp of this DetailedAthlete.

        The athlete's FTP (Functional Threshold Power).  # noqa: E501

        :param ftp: The ftp of this DetailedAthlete.  # noqa: E501
        :type: int
        """

        self._ftp = ftp

    @property
    def weight(self):
        """Gets the weight of this DetailedAthlete.  # noqa: E501

        The athlete's weight.  # noqa: E501

        :return: The weight of this DetailedAthlete.  # noqa: E501
        :rtype: float
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """Sets the weight of this DetailedAthlete.

        The athlete's weight.  # noqa: E501

        :param weight: The weight of this DetailedAthlete.  # noqa: E501
        :type: float
        """

        self._weight = weight

    @property
    def clubs(self):
        """Gets the clubs of this DetailedAthlete.  # noqa: E501

        The athlete's clubs.  # noqa: E501

        :return: The clubs of this DetailedAthlete.  # noqa: E501
        :rtype: list[SummaryClub]
        """
        return self._clubs

    @clubs.setter
    def clubs(self, clubs):
        """Sets the clubs of this DetailedAthlete.

        The athlete's clubs.  # noqa: E501

        :param clubs: The clubs of this DetailedAthlete.  # noqa: E501
        :type: list[SummaryClub]
        """

        self._clubs = clubs

    @property
    def bikes(self):
        """Gets the bikes of this DetailedAthlete.  # noqa: E501

        The athlete's bikes.  # noqa: E501

        :return: The bikes of this DetailedAthlete.  # noqa: E501
        :rtype: list[SummaryGear]
        """
        return self._bikes

    @bikes.setter
    def bikes(self, bikes):
        """Sets the bikes of this DetailedAthlete.

        The athlete's bikes.  # noqa: E501

        :param bikes: The bikes of this DetailedAthlete.  # noqa: E501
        :type: list[SummaryGear]
        """

        self._bikes = bikes

    @property
    def shoes(self):
        """Gets the shoes of this DetailedAthlete.  # noqa: E501

        The athlete's shoes.  # noqa: E501

        :return: The shoes of this DetailedAthlete.  # noqa: E501
        :rtype: list[SummaryGear]
        """
        return self._shoes

    @shoes.setter
    def shoes(self, shoes):
        """Sets the shoes of this DetailedAthlete.

        The athlete's shoes.  # noqa: E501

        :param shoes: The shoes of this DetailedAthlete.  # noqa: E501
        :type: list[SummaryGear]
        """

        self._shoes = shoes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DetailedAthlete, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DetailedAthlete):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.meta_club import MetaClub  # noqa: F401,E501


class SummaryClub(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'resource_state': 'int',
        'name': 'str',
        'profile_medium': 'str',
        'cover_photo': 'str',
        'cover_photo_small': 'str',
        'sport_type': 'str',
        'city': 'str',
        'state': 'str',
        'country': 'str',
        'private': 'bool',
        'member_count': 'int',
        'featured': 'bool',
        'verified': 'bool',
        'url': 'str'
    }

    attribute_map = {
        'id': 'id',
        'resource_state': 'resource_state',
        'name': 'name',
        'profile_medium': 'profile_medium',
        'cover_photo': 'cover_photo',
        'cover_photo_small': 'cover_photo_small',
        'sport_type': 'sport_type',
        'city': 'city',
        'state': 'state',
        'country': 'country',
        'private': 'private',
        'member_count': 'member_count',
        'featured': 'featured',
        'verified': 'verified',
        'url': 'url'
    }

    def __init__(self, id=None, resource_state=None, name=None, profile_medium=None, cover_photo=None, cover_photo_small=None, sport_type=None, city=None, state=None, country=None, private=None, member_count=None, featured=None, verified=None, url=None):  # noqa: E501
        """SummaryClub - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._resource_state = None
        self._name = None
        self._profile_medium = None
        self._cover_photo = None
        self._cover_photo_small = None
        self._sport_type = None
        self._city = None
        self._state = None
        self._country = None
        self._private = None
        self._member_count = None
        self._featured = None
        self._verified = None
        self._url = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if resource_state is not None:
            self.resource_state = resource_state
        if name is not None:
            self.name = name
        if profile_medium is not None:
            self.profile_medium = profile_medium
        if cover_photo is not None:
            self.cover_photo = cover_photo
        if cover_photo_small is not None:
            self.cover_photo_small = cover_photo_small
        if sport_type is not None:
            self.sport_type = sport_type
        if city is not None:
            self.city = city
        if state is not None:
            self.state = state
        if country is not None:
            self.country = country
        if private is not None:
            self.private = private
        if member_count is not None:
            self.member_count = member_count
        if featured is not None:
            self.featured = featured
        if verified is not None:
            self.verified = verified
        if url is not None:
            self.url = url

    @property
    def id(self):
        """Gets the id of this SummaryClub.  # noqa: E501

        The club's unique identifier.  # noqa: E501

        :return: The id of this SummaryClub.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SummaryClub.

        The club's unique identifier.  # noqa: E501

        :param id: The id of this SummaryClub.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def resource_state(self):
        """Gets the resource_state of this SummaryClub.  # noqa: E501

        Resource state, indicates level of detail. Possible values: 1 -> \"meta\", 2 -> \"summary\", 3 -> \"detail\"  # noqa: E501

        :return: The resource_state of this SummaryClub.  # noqa: E501
        :rtype: int
        """
        return self._resource_state

    @resource_state.setter
    def resource_state(self, resource_state):
        """Sets the resource_state of this SummaryClub.

        Resource state, indicates level of detail. Possible values: 1 -> \"meta\", 2 -> \"summary\", 3 -> \"detail\"  # noqa: E501

        :param resource_state: The resource_state of this SummaryClub.  # noqa: E501
        :type: int
        """

        self._resource_state = resource_state

    @property
    def name(self):
        """Gets the name of this SummaryClub.  # noqa: E501

        The club's name.  # noqa: E501

        :return: The name of this SummaryClub.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SummaryClub.

        The club's name.  # noqa: E501

        :param name: The name of this SummaryClub.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def profile_medium(self):
        """Gets the profile_medium of this SummaryClub.  # noqa: E501

        URL to a 60x60 pixel profile picture.  # noqa: E501

        :return: The profile_medium of this SummaryClub.  # noqa: E501
        :rtype: str
        """
        return self._profile_medium

    @profile_medium.setter
    def profile_medium(self, profile_medium):
        """Sets the profile_medium of this SummaryClub.

        URL to a 60x60 pixel profile picture.  # noqa: E501

        :param profile_medium: The profile_medium of this SummaryClub.  # noqa: E501
        :type: str
        """

        self._profile_medium = profile_medium

    @property
    def cover_photo(self):
        """Gets the cover_photo of this SummaryClub.  # noqa: E501

        URL to a ~1185x580 pixel cover photo.  # noqa: E501

        :return: The cover_photo of this SummaryClub.  # noqa: E501
        :rtype: str
        """
        return self._cover_photo

    @cover_photo.setter
    def cover_photo(self, cover_photo):
        """Sets the cover_photo of this SummaryClub.

        URL to a ~1185x580 pixel cover photo.  # noqa: E501

        :param cover_photo: The cover_photo of this SummaryClub.  # noqa: E501
        :type: str
        """

        self._cover_photo = cover_photo

    @property
    def cover_photo_small(self):
        """Gets the cover_photo_small of this SummaryClub.  # noqa: E501

        URL to a ~360x176  pixel cover photo.  # noqa: E501

        :return: The cover_photo_small of this SummaryClub.  # noqa: E501
        :rtype: str
        """
        return self._cover_photo_small

    @cover_photo_small.setter
    def cover_photo_small(self, cover_photo_small):
        """Sets the cover_photo_small of this SummaryClub.

        URL to a ~360x176  pixel cover photo.  # noqa: E501

        :param cover_photo_small: The cover_photo_small of this SummaryClub.  # noqa: E501
        :type: str
        """

        self._cover_photo_small = cover_photo_small

    @property
    def sport_type(self):
        """Gets the sport_type of this SummaryClub.  # noqa: E501


        :return: The sport_type of this SummaryClub.  # noqa: E501
        :rtype: str
        """
        return self._sport_type

    @sport_type.setter
    def sport_type(self, sport_type):
        """Sets the sport_type of this SummaryClub.


        :param sport_type: The sport_type of this SummaryClub.  # noqa: E501
        :type: str
        """
        allowed_values = ["cycling", "running", "triathlon", "other"]  # noqa: E501
        if sport_type not in allowed_values:
            raise ValueError(
                "Invalid value for `sport_type` ({0}), must be one of {1}"  # noqa: E501
                .format(sport_type, allowed_values)
            )

        self._sport_type = sport_type

    @property
    def city(self):
        """Gets the city of this SummaryClub.  # noqa: E501

        The club's city.  # noqa: E501

        :return: The city of this SummaryClub.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this SummaryClub.

        The club's city.  # noqa: E501

        :param city: The city of this SummaryClub.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state(self):
        """Gets the state of this SummaryClub.  # noqa: E501

        The club's state or geographical region.  # noqa: E501

        :return: The state of this SummaryClub.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this SummaryClub.

        The club's state or geographical region.  # noqa: E501

        :param state: The state of this SummaryClub.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def country(self):
        """Gets the country of this SummaryClub.  # noqa: E501

        The club's country.  # noqa: E501

        :return: The country of this SummaryClub.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this SummaryClub.

        The club's country.  # noqa: E501

        :param country: The country of this SummaryClub.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def private(self):
        """Gets the private of this SummaryClub.  # noqa: E501

        Whether the club is private.  # noqa: E501

        :return: The private of this SummaryClub.  # noqa: E501
        :rtype: bool
        """
        return self._private

    @private.setter
    def private(self, private):
        """Sets the private of this SummaryClub.

        Whether the club is private.  # noqa: E501

        :param private: The private of this SummaryClub.  # noqa: E501
        :type: bool
        """

        self._private = private

    @property
    def member_count(self):
        """Gets the member_count of this SummaryClub.  # noqa: E501

        The club's member count.  # noqa: E501

        :return: The member_count of this SummaryClub.  # noqa: E501
        :rtype: int
        """
        return self._member_count

    @member_count.setter
    def member_count(self, member_count):
        """Sets the member_count of this SummaryClub.

        The club's member count.  # noqa: E501

        :param member_count: The member_count of this SummaryClub.  # noqa: E501
        :type: int
        """

        self._member_count = member_count

    @property
    def featured(self):
        """Gets the featured of this SummaryClub.  # noqa: E501

        Whether the club is featured or not.  # noqa: E501

        :return: The featured of this SummaryClub.  # noqa: E501
        :rtype: bool
        """
        return self._featured

    @featured.setter
    def featured(self, featured):
        """Sets the featured of this SummaryClub.

        Whether the club is featured or not.  # noqa: E501

        :param featured: The featured of this SummaryClub.  # noqa: E501
        :type: bool
        """

        self._featured = featured

    @property
    def verified(self):
        """Gets the verified of this SummaryClub.  # noqa: E501

        Whether the club is verified or not.  # noqa: E501

        :return: The verified of this SummaryClub.  # noqa: E501
        :rtype: bool
        """
        return self._verified

    @verified.setter
    def verified(self, verified):
        """Sets the verified of this SummaryClub.

        Whether the club is verified or not.  # noqa: E501

        :param verified: The verified of this SummaryClub.  # noqa: E501
        :type: bool
        """

        self._verified = verified

    @property
    def url(self):
        """Gets the url of this SummaryClub.  # noqa: E501

        The club's vanity URL.  # noqa: E501

        :return: The url of this SummaryClub.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this SummaryClub.

        The club's vanity URL.  # noqa: E501

        :param url: The url of this SummaryClub.  # noqa: E501
        :type: str
        """

        self._url = url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SummaryClub, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SummaryClub):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.polyline_map import PolylineMap  # noqa: F401,E501
from swagger_client.models.route_direction import RouteDirection  # noqa: F401,E501
from swagger_client.models.summary_athlete import SummaryAthlete  # noqa: F401,E501
from swagger_client.models.summary_segment import SummarySegment  # noqa: F401,E501


class Route(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'athlete': 'SummaryAthlete',
        'description': 'str',
        'distance': 'float',
        'elevation_gain': 'float',
        'id': 'int',
        'map': 'PolylineMap',
        'name': 'str',
        'private': 'bool',
        'starred': 'bool',
        'timestamp': 'int',
        'type': 'int',
        'sub_type': 'int',
        'segments': 'list[SummarySegment]',
        'directions': 'list[RouteDirection]'
    }

    attribute_map = {
        'athlete': 'athlete',
        'description': 'description',
        'distance': 'distance',
        'elevation_gain': 'elevation_gain',
        'id': 'id',
        'map': 'map',
        'name': 'name',
        'private': 'private',
        'starred': 'starred',
        'timestamp': 'timestamp',
        'type': 'type',
        'sub_type': 'sub_type',
        'segments': 'segments',
        'directions': 'directions'
    }

    def __init__(self, athlete=None, description=None, distance=None, elevation_gain=None, id=None, map=None, name=None, private=None, starred=None, timestamp=None, type=None, sub_type=None, segments=None, directions=None):  # noqa: E501
        """Route - a model defined in Swagger"""  # noqa: E501

        self._athlete = None
        self._description = None
        self._distance = None
        self._elevation_gain = None
        self._id = None
        self._map = None
        self._name = None
        self._private = None
        self._starred = None
        self._timestamp = None
        self._type = None
        self._sub_type = None
        self._segments = None
        self._directions = None
        self.discriminator = None

        if athlete is not None:
            self.athlete = athlete
        if description is not None:
            self.description = description
        if distance is not None:
            self.distance = distance
        if elevation_gain is not None:
            self.elevation_gain = elevation_gain
        if id is not None:
            self.id = id
        if map is not None:
            self.map = map
        if name is not None:
            self.name = name
        if private is not None:
            self.private = private
        if starred is not None:
            self.starred = starred
        if timestamp is not None:
            self.timestamp = timestamp
        if type is not None:
            self.type = type
        if sub_type is not None:
            self.sub_type = sub_type
        if segments is not None:
            self.segments = segments
        if directions is not None:
            self.directions = directions

    @property
    def athlete(self):
        """Gets the athlete of this Route.  # noqa: E501


        :return: The athlete of this Route.  # noqa: E501
        :rtype: SummaryAthlete
        """
        return self._athlete

    @athlete.setter
    def athlete(self, athlete):
        """Sets the athlete of this Route.


        :param athlete: The athlete of this Route.  # noqa: E501
        :type: SummaryAthlete
        """

        self._athlete = athlete

    @property
    def description(self):
        """Gets the description of this Route.  # noqa: E501

        The description of the route  # noqa: E501

        :return: The description of this Route.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Route.

        The description of the route  # noqa: E501

        :param description: The description of this Route.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def distance(self):
        """Gets the distance of this Route.  # noqa: E501

        The route's distance, in meters  # noqa: E501

        :return: The distance of this Route.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this Route.

        The route's distance, in meters  # noqa: E501

        :param distance: The distance of this Route.  # noqa: E501
        :type: float
        """

        self._distance = distance

    @property
    def elevation_gain(self):
        """Gets the elevation_gain of this Route.  # noqa: E501

        The route's elevation gain.  # noqa: E501

        :return: The elevation_gain of this Route.  # noqa: E501
        :rtype: float
        """
        return self._elevation_gain

    @elevation_gain.setter
    def elevation_gain(self, elevation_gain):
        """Sets the elevation_gain of this Route.

        The route's elevation gain.  # noqa: E501

        :param elevation_gain: The elevation_gain of this Route.  # noqa: E501
        :type: float
        """

        self._elevation_gain = elevation_gain

    @property
    def id(self):
        """Gets the id of this Route.  # noqa: E501

        The unique identifier of this route  # noqa: E501

        :return: The id of this Route.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Route.

        The unique identifier of this route  # noqa: E501

        :param id: The id of this Route.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def map(self):
        """Gets the map of this Route.  # noqa: E501


        :return: The map of this Route.  # noqa: E501
        :rtype: PolylineMap
        """
        return self._map

    @map.setter
    def map(self, map):
        """Sets the map of this Route.


        :param map: The map of this Route.  # noqa: E501
        :type: PolylineMap
        """

        self._map = map

    @property
    def name(self):
        """Gets the name of this Route.  # noqa: E501

        The name of this route  # noqa: E501

        :return: The name of this Route.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Route.

        The name of this route  # noqa: E501

        :param name: The name of this Route.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def private(self):
        """Gets the private of this Route.  # noqa: E501

        Whether this route is private  # noqa: E501

        :return: The private of this Route.  # noqa: E501
        :rtype: bool
        """
        return self._private

    @private.setter
    def private(self, private):
        """Sets the private of this Route.

        Whether this route is private  # noqa: E501

        :param private: The private of this Route.  # noqa: E501
        :type: bool
        """

        self._private = private

    @property
    def starred(self):
        """Gets the starred of this Route.  # noqa: E501

        Whether this route is starred by the logged-in athlete  # noqa: E501

        :return: The starred of this Route.  # noqa: E501
        :rtype: bool
        """
        return self._starred

    @starred.setter
    def starred(self, starred):
        """Sets the starred of this Route.

        Whether this route is starred by the logged-in athlete  # noqa: E501

        :param starred: The starred of this Route.  # noqa: E501
        :type: bool
        """

        self._starred = starred

    @property
    def timestamp(self):
        """Gets the timestamp of this Route.  # noqa: E501


        :return: The timestamp of this Route.  # noqa: E501
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this Route.


        :param timestamp: The timestamp of this Route.  # noqa: E501
        :type: int
        """

        self._timestamp = timestamp

    @property
    def type(self):
        """Gets the type of this Route.  # noqa: E501

        This route's type (1 for ride, 2 for runs)  # noqa: E501

        :return: The type of this Route.  # noqa: E501
        :rtype: int
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Route.

        This route's type (1 for ride, 2 for runs)  # noqa: E501

        :param type: The type of this Route.  # noqa: E501
        :type: int
        """

        self._type = type

    @property
    def sub_type(self):
        """Gets the sub_type of this Route.  # noqa: E501

        This route's sub-type (1 for road, 2 for mountain bike, 3 for cross, 4 for trail, 5 for mixed)  # noqa: E501

        :return: The sub_type of this Route.  # noqa: E501
        :rtype: int
        """
        return self._sub_type

    @sub_type.setter
    def sub_type(self, sub_type):
        """Sets the sub_type of this Route.

        This route's sub-type (1 for road, 2 for mountain bike, 3 for cross, 4 for trail, 5 for mixed)  # noqa: E501

        :param sub_type: The sub_type of this Route.  # noqa: E501
        :type: int
        """

        self._sub_type = sub_type

    @property
    def segments(self):
        """Gets the segments of this Route.  # noqa: E501

        The segments traversed by this route  # noqa: E501

        :return: The segments of this Route.  # noqa: E501
        :rtype: list[SummarySegment]
        """
        return self._segments

    @segments.setter
    def segments(self, segments):
        """Sets the segments of this Route.

        The segments traversed by this route  # noqa: E501

        :param segments: The segments of this Route.  # noqa: E501
        :type: list[SummarySegment]
        """

        self._segments = segments

    @property
    def directions(self):
        """Gets the directions of this Route.  # noqa: E501

        The directions of this route  # noqa: E501

        :return: The directions of this Route.  # noqa: E501
        :rtype: list[RouteDirection]
        """
        return self._directions

    @directions.setter
    def directions(self, directions):
        """Sets the directions of this Route.

        The directions of this route  # noqa: E501

        :param directions: The directions of this Route.  # noqa: E501
        :type: list[RouteDirection]
        """

        self._directions = directions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Route, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Route):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.timed_zone_distribution import TimedZoneDistribution  # noqa: F401,E501


class ActivityZone(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'score': 'int',
        'distribution_buckets': 'TimedZoneDistribution',
        'type': 'str',
        'sensor_based': 'bool',
        'points': 'int',
        'custom_zones': 'bool',
        'max': 'int'
    }

    attribute_map = {
        'score': 'score',
        'distribution_buckets': 'distribution_buckets',
        'type': 'type',
        'sensor_based': 'sensor_based',
        'points': 'points',
        'custom_zones': 'custom_zones',
        'max': 'max'
    }

    def __init__(self, score=None, distribution_buckets=None, type=None, sensor_based=None, points=None, custom_zones=None, max=None):  # noqa: E501
        """ActivityZone - a model defined in Swagger"""  # noqa: E501

        self._score = None
        self._distribution_buckets = None
        self._type = None
        self._sensor_based = None
        self._points = None
        self._custom_zones = None
        self._max = None
        self.discriminator = None

        if score is not None:
            self.score = score
        if distribution_buckets is not None:
            self.distribution_buckets = distribution_buckets
        if type is not None:
            self.type = type
        if sensor_based is not None:
            self.sensor_based = sensor_based
        if points is not None:
            self.points = points
        if custom_zones is not None:
            self.custom_zones = custom_zones
        if max is not None:
            self.max = max

    @property
    def score(self):
        """Gets the score of this ActivityZone.  # noqa: E501


        :return: The score of this ActivityZone.  # noqa: E501
        :rtype: int
        """
        return self._score

    @score.setter
    def score(self, score):
        """Sets the score of this ActivityZone.


        :param score: The score of this ActivityZone.  # noqa: E501
        :type: int
        """

        self._score = score

    @property
    def distribution_buckets(self):
        """Gets the distribution_buckets of this ActivityZone.  # noqa: E501


        :return: The distribution_buckets of this ActivityZone.  # noqa: E501
        :rtype: TimedZoneDistribution
        """
        return self._distribution_buckets

    @distribution_buckets.setter
    def distribution_buckets(self, distribution_buckets):
        """Sets the distribution_buckets of this ActivityZone.


        :param distribution_buckets: The distribution_buckets of this ActivityZone.  # noqa: E501
        :type: TimedZoneDistribution
        """

        self._distribution_buckets = distribution_buckets

    @property
    def type(self):
        """Gets the type of this ActivityZone.  # noqa: E501


        :return: The type of this ActivityZone.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ActivityZone.


        :param type: The type of this ActivityZone.  # noqa: E501
        :type: str
        """
        allowed_values = ["heartrate", "power"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def sensor_based(self):
        """Gets the sensor_based of this ActivityZone.  # noqa: E501


        :return: The sensor_based of this ActivityZone.  # noqa: E501
        :rtype: bool
        """
        return self._sensor_based

    @sensor_based.setter
    def sensor_based(self, sensor_based):
        """Sets the sensor_based of this ActivityZone.


        :param sensor_based: The sensor_based of this ActivityZone.  # noqa: E501
        :type: bool
        """

        self._sensor_based = sensor_based

    @property
    def points(self):
        """Gets the points of this ActivityZone.  # noqa: E501


        :return: The points of this ActivityZone.  # noqa: E501
        :rtype: int
        """
        return self._points

    @points.setter
    def points(self, points):
        """Sets the points of this ActivityZone.


        :param points: The points of this ActivityZone.  # noqa: E501
        :type: int
        """

        self._points = points

    @property
    def custom_zones(self):
        """Gets the custom_zones of this ActivityZone.  # noqa: E501


        :return: The custom_zones of this ActivityZone.  # noqa: E501
        :rtype: bool
        """
        return self._custom_zones

    @custom_zones.setter
    def custom_zones(self, custom_zones):
        """Sets the custom_zones of this ActivityZone.


        :param custom_zones: The custom_zones of this ActivityZone.  # noqa: E501
        :type: bool
        """

        self._custom_zones = custom_zones

    @property
    def max(self):
        """Gets the max of this ActivityZone.  # noqa: E501


        :return: The max of this ActivityZone.  # noqa: E501
        :rtype: int
        """
        return self._max

    @max.setter
    def max(self, max):
        """Sets the max of this ActivityZone.


        :param max: The max of this ActivityZone.  # noqa: E501
        :type: int
        """

        self._max = max

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ActivityZone, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActivityZone):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.segment_leaderboard_entry import SegmentLeaderboardEntry  # noqa: F401,E501


class SegmentLeaderboard(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'entry_count': 'int',
        'effort_count': 'int',
        'kom_type': 'str',
        'entries': 'list[SegmentLeaderboardEntry]'
    }

    attribute_map = {
        'entry_count': 'entry_count',
        'effort_count': 'effort_count',
        'kom_type': 'kom_type',
        'entries': 'entries'
    }

    def __init__(self, entry_count=None, effort_count=None, kom_type=None, entries=None):  # noqa: E501
        """SegmentLeaderboard - a model defined in Swagger"""  # noqa: E501

        self._entry_count = None
        self._effort_count = None
        self._kom_type = None
        self._entries = None
        self.discriminator = None

        if entry_count is not None:
            self.entry_count = entry_count
        if effort_count is not None:
            self.effort_count = effort_count
        if kom_type is not None:
            self.kom_type = kom_type
        if entries is not None:
            self.entries = entries

    @property
    def entry_count(self):
        """Gets the entry_count of this SegmentLeaderboard.  # noqa: E501

        The total number of entries for this leaderboard  # noqa: E501

        :return: The entry_count of this SegmentLeaderboard.  # noqa: E501
        :rtype: int
        """
        return self._entry_count

    @entry_count.setter
    def entry_count(self, entry_count):
        """Sets the entry_count of this SegmentLeaderboard.

        The total number of entries for this leaderboard  # noqa: E501

        :param entry_count: The entry_count of this SegmentLeaderboard.  # noqa: E501
        :type: int
        """

        self._entry_count = entry_count

    @property
    def effort_count(self):
        """Gets the effort_count of this SegmentLeaderboard.  # noqa: E501

        Deprecated, use entry_count  # noqa: E501

        :return: The effort_count of this SegmentLeaderboard.  # noqa: E501
        :rtype: int
        """
        return self._effort_count

    @effort_count.setter
    def effort_count(self, effort_count):
        """Sets the effort_count of this SegmentLeaderboard.

        Deprecated, use entry_count  # noqa: E501

        :param effort_count: The effort_count of this SegmentLeaderboard.  # noqa: E501
        :type: int
        """

        self._effort_count = effort_count

    @property
    def kom_type(self):
        """Gets the kom_type of this SegmentLeaderboard.  # noqa: E501


        :return: The kom_type of this SegmentLeaderboard.  # noqa: E501
        :rtype: str
        """
        return self._kom_type

    @kom_type.setter
    def kom_type(self, kom_type):
        """Sets the kom_type of this SegmentLeaderboard.


        :param kom_type: The kom_type of this SegmentLeaderboard.  # noqa: E501
        :type: str
        """
        allowed_values = ["kom", "cr"]  # noqa: E501
        if kom_type not in allowed_values:
            raise ValueError(
                "Invalid value for `kom_type` ({0}), must be one of {1}"  # noqa: E501
                .format(kom_type, allowed_values)
            )

        self._kom_type = kom_type

    @property
    def entries(self):
        """Gets the entries of this SegmentLeaderboard.  # noqa: E501


        :return: The entries of this SegmentLeaderboard.  # noqa: E501
        :rtype: list[SegmentLeaderboardEntry]
        """
        return self._entries

    @entries.setter
    def entries(self, entries):
        """Sets the entries of this SegmentLeaderboard.


        :param entries: The entries of this SegmentLeaderboard.  # noqa: E501
        :type: list[SegmentLeaderboardEntry]
        """

        self._entries = entries

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SegmentLeaderboard, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SegmentLeaderboard):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class SegmentEffortsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_efforts_by_segment_id(self, id, **kwargs):  # noqa: E501
        """List Segment Efforts  # noqa: E501

        Returns a set of the authenticated athlete's segment efforts for a given segment.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_efforts_by_segment_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the segment. (required)
        :param int page: Page number.
        :param int per_page: Number of items per page. Defaults to 30.
        :return: list[DetailedSegmentEffort]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_efforts_by_segment_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_efforts_by_segment_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_efforts_by_segment_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """List Segment Efforts  # noqa: E501

        Returns a set of the authenticated athlete's segment efforts for a given segment.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_efforts_by_segment_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the segment. (required)
        :param int page: Page number.
        :param int per_page: Number of items per page. Defaults to 30.
        :return: list[DetailedSegmentEffort]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'page', 'per_page']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_efforts_by_segment_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_efforts_by_segment_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'per_page' in params:
            query_params.append(('per_page', params['per_page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['strava_oauth']  # noqa: E501

        return self.api_client.call_api(
            '/segments/{id}/all_efforts', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DetailedSegmentEffort]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_segment_effort_by_id(self, id, **kwargs):  # noqa: E501
        """Get Segment Effort  # noqa: E501

        Returns a segment effort from an activity that is owned by the authenticated athlete.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_segment_effort_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the segment effort. (required)
        :return: DetailedSegmentEffort
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_segment_effort_by_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_segment_effort_by_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_segment_effort_by_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get Segment Effort  # noqa: E501

        Returns a segment effort from an activity that is owned by the authenticated athlete.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_segment_effort_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The identifier of the segment effort. (required)
        :return: DetailedSegmentEffort
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_segment_effort_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_segment_effort_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['strava_oauth']  # noqa: E501

        return self.api_client.call_api(
            '/segment_efforts/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DetailedSegmentEffort',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SegmentLeaderboardEntry(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'athlete_name': 'str',
        'elapsed_time': 'int',
        'moving_time': 'int',
        'start_date': 'datetime',
        'start_date_local': 'datetime',
        'rank': 'int'
    }

    attribute_map = {
        'athlete_name': 'athlete_name',
        'elapsed_time': 'elapsed_time',
        'moving_time': 'moving_time',
        'start_date': 'start_date',
        'start_date_local': 'start_date_local',
        'rank': 'rank'
    }

    def __init__(self, athlete_name=None, elapsed_time=None, moving_time=None, start_date=None, start_date_local=None, rank=None):  # noqa: E501
        """SegmentLeaderboardEntry - a model defined in Swagger"""  # noqa: E501

        self._athlete_name = None
        self._elapsed_time = None
        self._moving_time = None
        self._start_date = None
        self._start_date_local = None
        self._rank = None
        self.discriminator = None

        if athlete_name is not None:
            self.athlete_name = athlete_name
        if elapsed_time is not None:
            self.elapsed_time = elapsed_time
        if moving_time is not None:
            self.moving_time = moving_time
        if start_date is not None:
            self.start_date = start_date
        if start_date_local is not None:
            self.start_date_local = start_date_local
        if rank is not None:
            self.rank = rank

    @property
    def athlete_name(self):
        """Gets the athlete_name of this SegmentLeaderboardEntry.  # noqa: E501

        The public name of the athlete  # noqa: E501

        :return: The athlete_name of this SegmentLeaderboardEntry.  # noqa: E501
        :rtype: str
        """
        return self._athlete_name

    @athlete_name.setter
    def athlete_name(self, athlete_name):
        """Sets the athlete_name of this SegmentLeaderboardEntry.

        The public name of the athlete  # noqa: E501

        :param athlete_name: The athlete_name of this SegmentLeaderboardEntry.  # noqa: E501
        :type: str
        """

        self._athlete_name = athlete_name

    @property
    def elapsed_time(self):
        """Gets the elapsed_time of this SegmentLeaderboardEntry.  # noqa: E501

        The elapsed of the segment effort associated with this entry  # noqa: E501

        :return: The elapsed_time of this SegmentLeaderboardEntry.  # noqa: E501
        :rtype: int
        """
        return self._elapsed_time

    @elapsed_time.setter
    def elapsed_time(self, elapsed_time):
        """Sets the elapsed_time of this SegmentLeaderboardEntry.

        The elapsed of the segment effort associated with this entry  # noqa: E501

        :param elapsed_time: The elapsed_time of this SegmentLeaderboardEntry.  # noqa: E501
        :type: int
        """

        self._elapsed_time = elapsed_time

    @property
    def moving_time(self):
        """Gets the moving_time of this SegmentLeaderboardEntry.  # noqa: E501

        The moving of the segment effort associated with this entry  # noqa: E501

        :return: The moving_time of this SegmentLeaderboardEntry.  # noqa: E501
        :rtype: int
        """
        return self._moving_time

    @moving_time.setter
    def moving_time(self, moving_time):
        """Sets the moving_time of this SegmentLeaderboardEntry.

        The moving of the segment effort associated with this entry  # noqa: E501

        :param moving_time: The moving_time of this SegmentLeaderboardEntry.  # noqa: E501
        :type: int
        """

        self._moving_time = moving_time

    @property
    def start_date(self):
        """Gets the start_date of this SegmentLeaderboardEntry.  # noqa: E501

        The time at which the effort was started.  # noqa: E501

        :return: The start_date of this SegmentLeaderboardEntry.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this SegmentLeaderboardEntry.

        The time at which the effort was started.  # noqa: E501

        :param start_date: The start_date of this SegmentLeaderboardEntry.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def start_date_local(self):
        """Gets the start_date_local of this SegmentLeaderboardEntry.  # noqa: E501

        The time at which the effort was started in the local timezone.  # noqa: E501

        :return: The start_date_local of this SegmentLeaderboardEntry.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date_local

    @start_date_local.setter
    def start_date_local(self, start_date_local):
        """Sets the start_date_local of this SegmentLeaderboardEntry.

        The time at which the effort was started in the local timezone.  # noqa: E501

        :param start_date_local: The start_date_local of this SegmentLeaderboardEntry.  # noqa: E501
        :type: datetime
        """

        self._start_date_local = start_date_local

    @property
    def rank(self):
        """Gets the rank of this SegmentLeaderboardEntry.  # noqa: E501

        The rank of this entry in the leaderboard  # noqa: E501

        :return: The rank of this SegmentLeaderboardEntry.  # noqa: E501
        :rtype: int
        """
        return self._rank

    @rank.setter
    def rank(self, rank):
        """Sets the rank of this SegmentLeaderboardEntry.

        The rank of this entry in the leaderboard  # noqa: E501

        :param rank: The rank of this SegmentLeaderboardEntry.  # noqa: E501
        :type: int
        """

        self._rank = rank

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SegmentLeaderboardEntry, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SegmentLeaderboardEntry):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.lat_lng import LatLng  # noqa: F401,E501
from swagger_client.models.polyline_map import PolylineMap  # noqa: F401,E501
from swagger_client.models.summary_segment import SummarySegment  # noqa: F401,E501
from swagger_client.models.summary_segment_effort import SummarySegmentEffort  # noqa: F401,E501


class DetailedSegment(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'activity_type': 'str',
        'distance': 'float',
        'average_grade': 'float',
        'maximum_grade': 'float',
        'elevation_high': 'float',
        'elevation_low': 'float',
        'start_latlng': 'LatLng',
        'end_latlng': 'LatLng',
        'climb_category': 'int',
        'city': 'str',
        'state': 'str',
        'country': 'str',
        'private': 'bool',
        'athlete_pr_effort': 'SummarySegmentEffort',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'total_elevation_gain': 'float',
        'map': 'PolylineMap',
        'effort_count': 'int',
        'athlete_count': 'int',
        'hazardous': 'bool',
        'star_count': 'int'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'activity_type': 'activity_type',
        'distance': 'distance',
        'average_grade': 'average_grade',
        'maximum_grade': 'maximum_grade',
        'elevation_high': 'elevation_high',
        'elevation_low': 'elevation_low',
        'start_latlng': 'start_latlng',
        'end_latlng': 'end_latlng',
        'climb_category': 'climb_category',
        'city': 'city',
        'state': 'state',
        'country': 'country',
        'private': 'private',
        'athlete_pr_effort': 'athlete_pr_effort',
        'created_at': 'created_at',
        'updated_at': 'updated_at',
        'total_elevation_gain': 'total_elevation_gain',
        'map': 'map',
        'effort_count': 'effort_count',
        'athlete_count': 'athlete_count',
        'hazardous': 'hazardous',
        'star_count': 'star_count'
    }

    def __init__(self, id=None, name=None, activity_type=None, distance=None, average_grade=None, maximum_grade=None, elevation_high=None, elevation_low=None, start_latlng=None, end_latlng=None, climb_category=None, city=None, state=None, country=None, private=None, athlete_pr_effort=None, created_at=None, updated_at=None, total_elevation_gain=None, map=None, effort_count=None, athlete_count=None, hazardous=None, star_count=None):  # noqa: E501
        """DetailedSegment - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._name = None
        self._activity_type = None
        self._distance = None
        self._average_grade = None
        self._maximum_grade = None
        self._elevation_high = None
        self._elevation_low = None
        self._start_latlng = None
        self._end_latlng = None
        self._climb_category = None
        self._city = None
        self._state = None
        self._country = None
        self._private = None
        self._athlete_pr_effort = None
        self._created_at = None
        self._updated_at = None
        self._total_elevation_gain = None
        self._map = None
        self._effort_count = None
        self._athlete_count = None
        self._hazardous = None
        self._star_count = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if activity_type is not None:
            self.activity_type = activity_type
        if distance is not None:
            self.distance = distance
        if average_grade is not None:
            self.average_grade = average_grade
        if maximum_grade is not None:
            self.maximum_grade = maximum_grade
        if elevation_high is not None:
            self.elevation_high = elevation_high
        if elevation_low is not None:
            self.elevation_low = elevation_low
        if start_latlng is not None:
            self.start_latlng = start_latlng
        if end_latlng is not None:
            self.end_latlng = end_latlng
        if climb_category is not None:
            self.climb_category = climb_category
        if city is not None:
            self.city = city
        if state is not None:
            self.state = state
        if country is not None:
            self.country = country
        if private is not None:
            self.private = private
        if athlete_pr_effort is not None:
            self.athlete_pr_effort = athlete_pr_effort
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if total_elevation_gain is not None:
            self.total_elevation_gain = total_elevation_gain
        if map is not None:
            self.map = map
        if effort_count is not None:
            self.effort_count = effort_count
        if athlete_count is not None:
            self.athlete_count = athlete_count
        if hazardous is not None:
            self.hazardous = hazardous
        if star_count is not None:
            self.star_count = star_count

    @property
    def id(self):
        """Gets the id of this DetailedSegment.  # noqa: E501

        The unique identifier of this segment  # noqa: E501

        :return: The id of this DetailedSegment.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DetailedSegment.

        The unique identifier of this segment  # noqa: E501

        :param id: The id of this DetailedSegment.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this DetailedSegment.  # noqa: E501

        The name of this segment  # noqa: E501

        :return: The name of this DetailedSegment.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DetailedSegment.

        The name of this segment  # noqa: E501

        :param name: The name of this DetailedSegment.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def activity_type(self):
        """Gets the activity_type of this DetailedSegment.  # noqa: E501


        :return: The activity_type of this DetailedSegment.  # noqa: E501
        :rtype: str
        """
        return self._activity_type

    @activity_type.setter
    def activity_type(self, activity_type):
        """Sets the activity_type of this DetailedSegment.


        :param activity_type: The activity_type of this DetailedSegment.  # noqa: E501
        :type: str
        """
        allowed_values = ["Ride", "Run"]  # noqa: E501
        if activity_type not in allowed_values:
            raise ValueError(
                "Invalid value for `activity_type` ({0}), must be one of {1}"  # noqa: E501
                .format(activity_type, allowed_values)
            )

        self._activity_type = activity_type

    @property
    def distance(self):
        """Gets the distance of this DetailedSegment.  # noqa: E501

        The segment's distance, in meters  # noqa: E501

        :return: The distance of this DetailedSegment.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this DetailedSegment.

        The segment's distance, in meters  # noqa: E501

        :param distance: The distance of this DetailedSegment.  # noqa: E501
        :type: float
        """

        self._distance = distance

    @property
    def average_grade(self):
        """Gets the average_grade of this DetailedSegment.  # noqa: E501

        The segment's average grade, in percents  # noqa: E501

        :return: The average_grade of this DetailedSegment.  # noqa: E501
        :rtype: float
        """
        return self._average_grade

    @average_grade.setter
    def average_grade(self, average_grade):
        """Sets the average_grade of this DetailedSegment.

        The segment's average grade, in percents  # noqa: E501

        :param average_grade: The average_grade of this DetailedSegment.  # noqa: E501
        :type: float
        """

        self._average_grade = average_grade

    @property
    def maximum_grade(self):
        """Gets the maximum_grade of this DetailedSegment.  # noqa: E501

        The segments's maximum grade, in percents  # noqa: E501

        :return: The maximum_grade of this DetailedSegment.  # noqa: E501
        :rtype: float
        """
        return self._maximum_grade

    @maximum_grade.setter
    def maximum_grade(self, maximum_grade):
        """Sets the maximum_grade of this DetailedSegment.

        The segments's maximum grade, in percents  # noqa: E501

        :param maximum_grade: The maximum_grade of this DetailedSegment.  # noqa: E501
        :type: float
        """

        self._maximum_grade = maximum_grade

    @property
    def elevation_high(self):
        """Gets the elevation_high of this DetailedSegment.  # noqa: E501

        The segments's highest elevation, in meters  # noqa: E501

        :return: The elevation_high of this DetailedSegment.  # noqa: E501
        :rtype: float
        """
        return self._elevation_high

    @elevation_high.setter
    def elevation_high(self, elevation_high):
        """Sets the elevation_high of this DetailedSegment.

        The segments's highest elevation, in meters  # noqa: E501

        :param elevation_high: The elevation_high of this DetailedSegment.  # noqa: E501
        :type: float
        """

        self._elevation_high = elevation_high

    @property
    def elevation_low(self):
        """Gets the elevation_low of this DetailedSegment.  # noqa: E501

        The segments's lowest elevation, in meters  # noqa: E501

        :return: The elevation_low of this DetailedSegment.  # noqa: E501
        :rtype: float
        """
        return self._elevation_low

    @elevation_low.setter
    def elevation_low(self, elevation_low):
        """Sets the elevation_low of this DetailedSegment.

        The segments's lowest elevation, in meters  # noqa: E501

        :param elevation_low: The elevation_low of this DetailedSegment.  # noqa: E501
        :type: float
        """

        self._elevation_low = elevation_low

    @property
    def start_latlng(self):
        """Gets the start_latlng of this DetailedSegment.  # noqa: E501


        :return: The start_latlng of this DetailedSegment.  # noqa: E501
        :rtype: LatLng
        """
        return self._start_latlng

    @start_latlng.setter
    def start_latlng(self, start_latlng):
        """Sets the start_latlng of this DetailedSegment.


        :param start_latlng: The start_latlng of this DetailedSegment.  # noqa: E501
        :type: LatLng
        """

        self._start_latlng = start_latlng

    @property
    def end_latlng(self):
        """Gets the end_latlng of this DetailedSegment.  # noqa: E501


        :return: The end_latlng of this DetailedSegment.  # noqa: E501
        :rtype: LatLng
        """
        return self._end_latlng

    @end_latlng.setter
    def end_latlng(self, end_latlng):
        """Sets the end_latlng of this DetailedSegment.


        :param end_latlng: The end_latlng of this DetailedSegment.  # noqa: E501
        :type: LatLng
        """

        self._end_latlng = end_latlng

    @property
    def climb_category(self):
        """Gets the climb_category of this DetailedSegment.  # noqa: E501

        The category of the climb  # noqa: E501

        :return: The climb_category of this DetailedSegment.  # noqa: E501
        :rtype: int
        """
        return self._climb_category

    @climb_category.setter
    def climb_category(self, climb_category):
        """Sets the climb_category of this DetailedSegment.

        The category of the climb  # noqa: E501

        :param climb_category: The climb_category of this DetailedSegment.  # noqa: E501
        :type: int
        """
        if climb_category is not None and climb_category > 5:  # noqa: E501
            raise ValueError("Invalid value for `climb_category`, must be a value less than or equal to `5`")  # noqa: E501
        if climb_category is not None and climb_category < 0:  # noqa: E501
            raise ValueError("Invalid value for `climb_category`, must be a value greater than or equal to `0`")  # noqa: E501

        self._climb_category = climb_category

    @property
    def city(self):
        """Gets the city of this DetailedSegment.  # noqa: E501

        The segments's city.  # noqa: E501

        :return: The city of this DetailedSegment.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this DetailedSegment.

        The segments's city.  # noqa: E501

        :param city: The city of this DetailedSegment.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state(self):
        """Gets the state of this DetailedSegment.  # noqa: E501

        The segments's state or geographical region.  # noqa: E501

        :return: The state of this DetailedSegment.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this DetailedSegment.

        The segments's state or geographical region.  # noqa: E501

        :param state: The state of this DetailedSegment.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def country(self):
        """Gets the country of this DetailedSegment.  # noqa: E501

        The segment's country.  # noqa: E501

        :return: The country of this DetailedSegment.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this DetailedSegment.

        The segment's country.  # noqa: E501

        :param country: The country of this DetailedSegment.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def private(self):
        """Gets the private of this DetailedSegment.  # noqa: E501

        Whether this segment is private.  # noqa: E501

        :return: The private of this DetailedSegment.  # noqa: E501
        :rtype: bool
        """
        return self._private

    @private.setter
    def private(self, private):
        """Sets the private of this DetailedSegment.

        Whether this segment is private.  # noqa: E501

        :param private: The private of this DetailedSegment.  # noqa: E501
        :type: bool
        """

        self._private = private

    @property
    def athlete_pr_effort(self):
        """Gets the athlete_pr_effort of this DetailedSegment.  # noqa: E501


        :return: The athlete_pr_effort of this DetailedSegment.  # noqa: E501
        :rtype: SummarySegmentEffort
        """
        return self._athlete_pr_effort

    @athlete_pr_effort.setter
    def athlete_pr_effort(self, athlete_pr_effort):
        """Sets the athlete_pr_effort of this DetailedSegment.


        :param athlete_pr_effort: The athlete_pr_effort of this DetailedSegment.  # noqa: E501
        :type: SummarySegmentEffort
        """

        self._athlete_pr_effort = athlete_pr_effort

    @property
    def created_at(self):
        """Gets the created_at of this DetailedSegment.  # noqa: E501

        The time at which the segment was created.  # noqa: E501

        :return: The created_at of this DetailedSegment.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this DetailedSegment.

        The time at which the segment was created.  # noqa: E501

        :param created_at: The created_at of this DetailedSegment.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this DetailedSegment.  # noqa: E501

        The time at which the segment was last updated.  # noqa: E501

        :return: The updated_at of this DetailedSegment.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this DetailedSegment.

        The time at which the segment was last updated.  # noqa: E501

        :param updated_at: The updated_at of this DetailedSegment.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def total_elevation_gain(self):
        """Gets the total_elevation_gain of this DetailedSegment.  # noqa: E501

        The segment's total elevation gain.  # noqa: E501

        :return: The total_elevation_gain of this DetailedSegment.  # noqa: E501
        :rtype: float
        """
        return self._total_elevation_gain

    @total_elevation_gain.setter
    def total_elevation_gain(self, total_elevation_gain):
        """Sets the total_elevation_gain of this DetailedSegment.

        The segment's total elevation gain.  # noqa: E501

        :param total_elevation_gain: The total_elevation_gain of this DetailedSegment.  # noqa: E501
        :type: float
        """

        self._total_elevation_gain = total_elevation_gain

    @property
    def map(self):
        """Gets the map of this DetailedSegment.  # noqa: E501


        :return: The map of this DetailedSegment.  # noqa: E501
        :rtype: PolylineMap
        """
        return self._map

    @map.setter
    def map(self, map):
        """Sets the map of this DetailedSegment.


        :param map: The map of this DetailedSegment.  # noqa: E501
        :type: PolylineMap
        """

        self._map = map

    @property
    def effort_count(self):
        """Gets the effort_count of this DetailedSegment.  # noqa: E501

        The total number of efforts for this segment  # noqa: E501

        :return: The effort_count of this DetailedSegment.  # noqa: E501
        :rtype: int
        """
        return self._effort_count

    @effort_count.setter
    def effort_count(self, effort_count):
        """Sets the effort_count of this DetailedSegment.

        The total number of efforts for this segment  # noqa: E501

        :param effort_count: The effort_count of this DetailedSegment.  # noqa: E501
        :type: int
        """

        self._effort_count = effort_count

    @property
    def athlete_count(self):
        """Gets the athlete_count of this DetailedSegment.  # noqa: E501

        The number of unique athletes who have an effort for this segment  # noqa: E501

        :return: The athlete_count of this DetailedSegment.  # noqa: E501
        :rtype: int
        """
        return self._athlete_count

    @athlete_count.setter
    def athlete_count(self, athlete_count):
        """Sets the athlete_count of this DetailedSegment.

        The number of unique athletes who have an effort for this segment  # noqa: E501

        :param athlete_count: The athlete_count of this DetailedSegment.  # noqa: E501
        :type: int
        """

        self._athlete_count = athlete_count

    @property
    def hazardous(self):
        """Gets the hazardous of this DetailedSegment.  # noqa: E501

        Whether this segment is considered hazardous  # noqa: E501

        :return: The hazardous of this DetailedSegment.  # noqa: E501
        :rtype: bool
        """
        return self._hazardous

    @hazardous.setter
    def hazardous(self, hazardous):
        """Sets the hazardous of this DetailedSegment.

        Whether this segment is considered hazardous  # noqa: E501

        :param hazardous: The hazardous of this DetailedSegment.  # noqa: E501
        :type: bool
        """

        self._hazardous = hazardous

    @property
    def star_count(self):
        """Gets the star_count of this DetailedSegment.  # noqa: E501

        The number of stars for this segment  # noqa: E501

        :return: The star_count of this DetailedSegment.  # noqa: E501
        :rtype: int
        """
        return self._star_count

    @star_count.setter
    def star_count(self, star_count):
        """Sets the star_count of this DetailedSegment.

        The number of stars for this segment  # noqa: E501

        :param star_count: The star_count of this DetailedSegment.  # noqa: E501
        :type: int
        """

        self._star_count = star_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DetailedSegment, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DetailedSegment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ActivityTotal(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'count': 'int',
        'distance': 'float',
        'moving_time': 'int',
        'elapsed_time': 'int',
        'elevation_gain': 'float',
        'achievement_count': 'int'
    }

    attribute_map = {
        'count': 'count',
        'distance': 'distance',
        'moving_time': 'moving_time',
        'elapsed_time': 'elapsed_time',
        'elevation_gain': 'elevation_gain',
        'achievement_count': 'achievement_count'
    }

    def __init__(self, count=None, distance=None, moving_time=None, elapsed_time=None, elevation_gain=None, achievement_count=None):  # noqa: E501
        """ActivityTotal - a model defined in Swagger"""  # noqa: E501

        self._count = None
        self._distance = None
        self._moving_time = None
        self._elapsed_time = None
        self._elevation_gain = None
        self._achievement_count = None
        self.discriminator = None

        if count is not None:
            self.count = count
        if distance is not None:
            self.distance = distance
        if moving_time is not None:
            self.moving_time = moving_time
        if elapsed_time is not None:
            self.elapsed_time = elapsed_time
        if elevation_gain is not None:
            self.elevation_gain = elevation_gain
        if achievement_count is not None:
            self.achievement_count = achievement_count

    @property
    def count(self):
        """Gets the count of this ActivityTotal.  # noqa: E501

        The number of activities considered in this total.  # noqa: E501

        :return: The count of this ActivityTotal.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ActivityTotal.

        The number of activities considered in this total.  # noqa: E501

        :param count: The count of this ActivityTotal.  # noqa: E501
        :type: int
        """

        self._count = count

    @property
    def distance(self):
        """Gets the distance of this ActivityTotal.  # noqa: E501

        The total distance covered by the considered activities.  # noqa: E501

        :return: The distance of this ActivityTotal.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this ActivityTotal.

        The total distance covered by the considered activities.  # noqa: E501

        :param distance: The distance of this ActivityTotal.  # noqa: E501
        :type: float
        """

        self._distance = distance

    @property
    def moving_time(self):
        """Gets the moving_time of this ActivityTotal.  # noqa: E501

        The total moving time of the considered activities.  # noqa: E501

        :return: The moving_time of this ActivityTotal.  # noqa: E501
        :rtype: int
        """
        return self._moving_time

    @moving_time.setter
    def moving_time(self, moving_time):
        """Sets the moving_time of this ActivityTotal.

        The total moving time of the considered activities.  # noqa: E501

        :param moving_time: The moving_time of this ActivityTotal.  # noqa: E501
        :type: int
        """

        self._moving_time = moving_time

    @property
    def elapsed_time(self):
        """Gets the elapsed_time of this ActivityTotal.  # noqa: E501

        The total elapsed time of the considered activities.  # noqa: E501

        :return: The elapsed_time of this ActivityTotal.  # noqa: E501
        :rtype: int
        """
        return self._elapsed_time

    @elapsed_time.setter
    def elapsed_time(self, elapsed_time):
        """Sets the elapsed_time of this ActivityTotal.

        The total elapsed time of the considered activities.  # noqa: E501

        :param elapsed_time: The elapsed_time of this ActivityTotal.  # noqa: E501
        :type: int
        """

        self._elapsed_time = elapsed_time

    @property
    def elevation_gain(self):
        """Gets the elevation_gain of this ActivityTotal.  # noqa: E501

        The total elevation gain of the considered activities.  # noqa: E501

        :return: The elevation_gain of this ActivityTotal.  # noqa: E501
        :rtype: float
        """
        return self._elevation_gain

    @elevation_gain.setter
    def elevation_gain(self, elevation_gain):
        """Sets the elevation_gain of this ActivityTotal.

        The total elevation gain of the considered activities.  # noqa: E501

        :param elevation_gain: The elevation_gain of this ActivityTotal.  # noqa: E501
        :type: float
        """

        self._elevation_gain = elevation_gain

    @property
    def achievement_count(self):
        """Gets the achievement_count of this ActivityTotal.  # noqa: E501

        The total number of achievements of the considered activities.  # noqa: E501

        :return: The achievement_count of this ActivityTotal.  # noqa: E501
        :rtype: int
        """
        return self._achievement_count

    @achievement_count.setter
    def achievement_count(self, achievement_count):
        """Sets the achievement_count of this ActivityTotal.

        The total number of achievements of the considered activities.  # noqa: E501

        :param achievement_count: The achievement_count of this ActivityTotal.  # noqa: E501
        :type: int
        """

        self._achievement_count = achievement_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ActivityTotal, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActivityTotal):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Strava API v3

    Strava API  # noqa: E501

    OpenAPI spec version: 3.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from swagger_client.models.activity_type import ActivityType  # noqa: F401,E501
from swagger_client.models.lat_lng import LatLng  # noqa: F401,E501
from swagger_client.models.meta_activity import MetaActivity  # noqa: F401,E501
from swagger_client.models.meta_athlete import MetaAthlete  # noqa: F401,E501
from swagger_client.models.polyline_map import PolylineMap  # noqa: F401,E501


class SummaryActivity(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'external_id': 'str',
        'upload_id': 'int',
        'athlete': 'MetaAthlete',
        'name': 'str',
        'distance': 'float',
        'moving_time': 'int',
        'elapsed_time': 'int',
        'total_elevation_gain': 'float',
        'elev_high': 'float',
        'elev_low': 'float',
        'type': 'ActivityType',
        'start_date': 'datetime',
        'start_date_local': 'datetime',
        'timezone': 'str',
        'start_latlng': 'LatLng',
        'end_latlng': 'LatLng',
        'achievement_count': 'int',
        'kudos_count': 'int',
        'comment_count': 'int',
        'athlete_count': 'int',
        'photo_count': 'int',
        'total_photo_count': 'int',
        'map': 'PolylineMap',
        'trainer': 'bool',
        'commute': 'bool',
        'manual': 'bool',
        'private': 'bool',
        'flagged': 'bool',
        'workout_type': 'int',
        'average_speed': 'float',
        'max_speed': 'float',
        'has_kudoed': 'bool',
        'gear_id': 'str',
        'kilojoules': 'float',
        'average_watts': 'float',
        'device_watts': 'bool',
        'max_watts': 'int',
        'weighted_average_watts': 'int'
    }

    attribute_map = {
        'id': 'id',
        'external_id': 'external_id',
        'upload_id': 'upload_id',
        'athlete': 'athlete',
        'name': 'name',
        'distance': 'distance',
        'moving_time': 'moving_time',
        'elapsed_time': 'elapsed_time',
        'total_elevation_gain': 'total_elevation_gain',
        'elev_high': 'elev_high',
        'elev_low': 'elev_low',
        'type': 'type',
        'start_date': 'start_date',
        'start_date_local': 'start_date_local',
        'timezone': 'timezone',
        'start_latlng': 'start_latlng',
        'end_latlng': 'end_latlng',
        'achievement_count': 'achievement_count',
        'kudos_count': 'kudos_count',
        'comment_count': 'comment_count',
        'athlete_count': 'athlete_count',
        'photo_count': 'photo_count',
        'total_photo_count': 'total_photo_count',
        'map': 'map',
        'trainer': 'trainer',
        'commute': 'commute',
        'manual': 'manual',
        'private': 'private',
        'flagged': 'flagged',
        'workout_type': 'workout_type',
        'average_speed': 'average_speed',
        'max_speed': 'max_speed',
        'has_kudoed': 'has_kudoed',
        'gear_id': 'gear_id',
        'kilojoules': 'kilojoules',
        'average_watts': 'average_watts',
        'device_watts': 'device_watts',
        'max_watts': 'max_watts',
        'weighted_average_watts': 'weighted_average_watts'
    }

    def __init__(self, id=None, external_id=None, upload_id=None, athlete=None, name=None, distance=None, moving_time=None, elapsed_time=None, total_elevation_gain=None, elev_high=None, elev_low=None, type=None, start_date=None, start_date_local=None, timezone=None, start_latlng=None, end_latlng=None, achievement_count=None, kudos_count=None, comment_count=None, athlete_count=None, photo_count=None, total_photo_count=None, map=None, trainer=None, commute=None, manual=None, private=None, flagged=None, workout_type=None, average_speed=None, max_speed=None, has_kudoed=None, gear_id=None, kilojoules=None, average_watts=None, device_watts=None, max_watts=None, weighted_average_watts=None):  # noqa: E501
        """SummaryActivity - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._external_id = None
        self._upload_id = None
        self._athlete = None
        self._name = None
        self._distance = None
        self._moving_time = None
        self._elapsed_time = None
        self._total_elevation_gain = None
        self._elev_high = None
        self._elev_low = None
        self._type = None
        self._start_date = None
        self._start_date_local = None
        self._timezone = None
        self._start_latlng = None
        self._end_latlng = None
        self._achievement_count = None
        self._kudos_count = None
        self._comment_count = None
        self._athlete_count = None
        self._photo_count = None
        self._total_photo_count = None
        self._map = None
        self._trainer = None
        self._commute = None
        self._manual = None
        self._private = None
        self._flagged = None
        self._workout_type = None
        self._average_speed = None
        self._max_speed = None
        self._has_kudoed = None
        self._gear_id = None
        self._kilojoules = None
        self._average_watts = None
        self._device_watts = None
        self._max_watts = None
        self._weighted_average_watts = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if external_id is not None:
            self.external_id = external_id
        if upload_id is not None:
            self.upload_id = upload_id
        if athlete is not None:
            self.athlete = athlete
        if name is not None:
            self.name = name
        if distance is not None:
            self.distance = distance
        if moving_time is not None:
            self.moving_time = moving_time
        if elapsed_time is not None:
            self.elapsed_time = elapsed_time
        if total_elevation_gain is not None:
            self.total_elevation_gain = total_elevation_gain
        if elev_high is not None:
            self.elev_high = elev_high
        if elev_low is not None:
            self.elev_low = elev_low
        if type is not None:
            self.type = type
        if start_date is not None:
            self.start_date = start_date
        if start_date_local is not None:
            self.start_date_local = start_date_local
        if timezone is not None:
            self.timezone = timezone
        if start_latlng is not None:
            self.start_latlng = start_latlng
        if end_latlng is not None:
            self.end_latlng = end_latlng
        if achievement_count is not None:
            self.achievement_count = achievement_count
        if kudos_count is not None:
            self.kudos_count = kudos_count
        if comment_count is not None:
            self.comment_count = comment_count
        if athlete_count is not None:
            self.athlete_count = athlete_count
        if photo_count is not None:
            self.photo_count = photo_count
        if total_photo_count is not None:
            self.total_photo_count = total_photo_count
        if map is not None:
            self.map = map
        if trainer is not None:
            self.trainer = trainer
        if commute is not None:
            self.commute = commute
        if manual is not None:
            self.manual = manual
        if private is not None:
            self.private = private
        if flagged is not None:
            self.flagged = flagged
        if workout_type is not None:
            self.workout_type = workout_type
        if average_speed is not None:
            self.average_speed = average_speed
        if max_speed is not None:
            self.max_speed = max_speed
        if has_kudoed is not None:
            self.has_kudoed = has_kudoed
        if gear_id is not None:
            self.gear_id = gear_id
        if kilojoules is not None:
            self.kilojoules = kilojoules
        if average_watts is not None:
            self.average_watts = average_watts
        if device_watts is not None:
            self.device_watts = device_watts
        if max_watts is not None:
            self.max_watts = max_watts
        if weighted_average_watts is not None:
            self.weighted_average_watts = weighted_average_watts

    @property
    def id(self):
        """Gets the id of this SummaryActivity.  # noqa: E501

        The unique identifier of the activity  # noqa: E501

        :return: The id of this SummaryActivity.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SummaryActivity.

        The unique identifier of the activity  # noqa: E501

        :param id: The id of this SummaryActivity.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def external_id(self):
        """Gets the external_id of this SummaryActivity.  # noqa: E501

        The identifier provided at upload time  # noqa: E501

        :return: The external_id of this SummaryActivity.  # noqa: E501
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this SummaryActivity.

        The identifier provided at upload time  # noqa: E501

        :param external_id: The external_id of this SummaryActivity.  # noqa: E501
        :type: str
        """

        self._external_id = external_id

    @property
    def upload_id(self):
        """Gets the upload_id of this SummaryActivity.  # noqa: E501

        The identifier of the upload that resulted in this activity  # noqa: E501

        :return: The upload_id of this SummaryActivity.  # noqa: E501
        :rtype: int
        """
        return self._upload_id

    @upload_id.setter
    def upload_id(self, upload_id):
        """Sets the upload_id of this SummaryActivity.

        The identifier of the upload that resulted in this activity  # noqa: E501

        :param upload_id: The upload_id of this SummaryActivity.  # noqa: E501
        :type: int
        """

        self._upload_id = upload_id

    @property
    def athlete(self):
        """Gets the athlete of this SummaryActivity.  # noqa: E501


        :return: The athlete of this SummaryActivity.  # noqa: E501
        :rtype: MetaAthlete
        """
        return self._athlete

    @athlete.setter
    def athlete(self, athlete):
        """Sets the athlete of this SummaryActivity.


        :param athlete: The athlete of this SummaryActivity.  # noqa: E501
        :type: MetaAthlete
        """

        self._athlete = athlete

    @property
    def name(self):
        """Gets the name of this SummaryActivity.  # noqa: E501

        The name of the activity  # noqa: E501

        :return: The name of this SummaryActivity.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SummaryActivity.

        The name of the activity  # noqa: E501

        :param name: The name of this SummaryActivity.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def distance(self):
        """Gets the distance of this SummaryActivity.  # noqa: E501

        The activity's distance, in meters  # noqa: E501

        :return: The distance of this SummaryActivity.  # noqa: E501
        :rtype: float
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this SummaryActivity.

        The activity's distance, in meters  # noqa: E501

        :param distance: The distance of this SummaryActivity.  # noqa: E501
        :type: float
        """

        self._distance = distance

    @property
    def moving_time(self):
        """Gets the moving_time of this SummaryActivity.  # noqa: E501

        The activity's moving time, in seconds  # noqa: E501

        :return: The moving_time of this SummaryActivity.  # noqa: E501
        :rtype: int
        """
        return self._moving_time

    @moving_time.setter
    def moving_time(self, moving_time):
        """Sets the moving_time of this SummaryActivity.

        The activity's moving time, in seconds  # noqa: E501

        :param moving_time: The moving_time of this SummaryActivity.  # noqa: E501
        :type: int
        """

        self._moving_time = moving_time

    @property
    def elapsed_time(self):
        """Gets the elapsed_time of this SummaryActivity.  # noqa: E501

        The activity's elapsed time, in seconds  # noqa: E501

        :return: The elapsed_time of this SummaryActivity.  # noqa: E501
        :rtype: int
        """
        return self._elapsed_time

    @elapsed_time.setter
    def elapsed_time(self, elapsed_time):
        """Sets the elapsed_time of this SummaryActivity.

        The activity's elapsed time, in seconds  # noqa: E501

        :param elapsed_time: The elapsed_time of this SummaryActivity.  # noqa: E501
        :type: int
        """

        self._elapsed_time = elapsed_time

    @property
    def total_elevation_gain(self):
        """Gets the total_elevation_gain of this SummaryActivity.  # noqa: E501

        The activity's total elevation gain.  # noqa: E501

        :return: The total_elevation_gain of this SummaryActivity.  # noqa: E501
        :rtype: float
        """
        return self._total_elevation_gain

    @total_elevation_gain.setter
    def total_elevation_gain(self, total_elevation_gain):
        """Sets the total_elevation_gain of this SummaryActivity.

        The activity's total elevation gain.  # noqa: E501

        :param total_elevation_gain: The total_elevation_gain of this SummaryActivity.  # noqa: E501
        :type: float
        """

        self._total_elevation_gain = total_elevation_gain

    @property
    def elev_high(self):
        """Gets the elev_high of this SummaryActivity.  # noqa: E501

        The activity's highest elevation, in meters  # noqa: E501

        :return: The elev_high of this SummaryActivity.  # noqa: E501
        :rtype: float
        """
        return self._elev_high

    @elev_high.setter
    def elev_high(self, elev_high):
        """Sets the elev_high of this SummaryActivity.

        The activity's highest elevation, in meters  # noqa: E501

        :param elev_high: The elev_high of this SummaryActivity.  # noqa: E501
        :type: float
        """

        self._elev_high = elev_high

    @property
    def elev_low(self):
        """Gets the elev_low of this SummaryActivity.  # noqa: E501

        The activity's lowest elevation, in meters  # noqa: E501

        :return: The elev_low of this SummaryActivity.  # noqa: E501
        :rtype: float
        """
        return self._elev_low

    @elev_low.setter
    def elev_low(self, elev_low):
        """Sets the elev_low of this SummaryActivity.

        The activity's lowest elevation, in meters  # noqa: E501

        :param elev_low: The elev_low of this SummaryActivity.  # noqa: E501
        :type: float
        """

        self._elev_low = elev_low

    @property
    def type(self):
        """Gets the type of this SummaryActivity.  # noqa: E501


        :return: The type of this SummaryActivity.  # noqa: E501
        :rtype: ActivityType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SummaryActivity.


        :param type: The type of this SummaryActivity.  # noqa: E501
        :type: ActivityType
        """

        self._type = type

    @property
    def start_date(self):
        """Gets the start_date of this SummaryActivity.  # noqa: E501

        The time at which the activity was started.  # noqa: E501

        :return: The start_date of this SummaryActivity.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this SummaryActivity.

        The time at which the activity was started.  # noqa: E501

        :param start_date: The start_date of this SummaryActivity.  # noqa: E501
        :type: datetime
        """

        self._start_date = start_date

    @property
    def start_date_local(self):
        """Gets the start_date_local of this SummaryActivity.  # noqa: E501

        The time at which the activity was started in the local timezone.  # noqa: E501

        :return: The start_date_local of this SummaryActivity.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date_local

    @start_date_local.setter
    def start_date_local(self, start_date_local):
        """Sets the start_date_local of this SummaryActivity.

        The time at which the activity was started in the local timezone.  # noqa: E501

        :param start_date_local: The start_date_local of this SummaryActivity.  # noqa: E501
        :type: datetime
        """

        self._start_date_local = start_date_local

    @property
    def timezone(self):
        """Gets the timezone of this SummaryActivity.  # noqa: E501

        The timezone of the activity  # noqa: E501

        :return: The timezone of this SummaryActivity.  # noqa: E501
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """Sets the timezone of this SummaryActivity.

        The timezone of the activity  # noqa: E501

        :param timezone: The timezone of this SummaryActivity.  # noqa: E501
        :type: str
        """

        self._timezone = timezone

    @property
    def start_latlng(self):
        """Gets the start_latlng of this SummaryActivity.  # noqa: E501


        :return: The start_latlng of this SummaryActivity.  # noqa: E501
        :rtype: LatLng
        """
        return self._start_latlng

    @start_latlng.setter
    def start_latlng(self, start_latlng):
        """Sets the start_latlng of this SummaryActivity.


        :param start_latlng: The start_latlng of this SummaryActivity.  # noqa: E501
        :type: LatLng
        """

        self._start_latlng = start_latlng

    @property
    def end_latlng(self):
        """Gets the end_latlng of this SummaryActivity.  # noqa: E501


        :return: The end_latlng of this SummaryActivity.  # noqa: E501
        :rtype: LatLng
        """
        return self._end_latlng

    @end_latlng.setter
    def end_latlng(self, end_latlng):
        """Sets the end_latlng of this SummaryActivity.


        :param end_latlng: The end_latlng of this SummaryActivity.  # noqa: E501
        :type: LatLng
        """

        self._end_latlng = end_latlng

    @property
    def achievement_count(self):
        """Gets the achievement_count of this SummaryActivity.  # noqa: E501

        The number of achievements gained during this activity  # noqa: E501

        :return: The achievement_count of this SummaryActivity.  # noqa: E501
        :rtype: int
        """
        return self._achievement_count

    @achievement_count.setter
    def achievement_count(self, achievement_count):
        """Sets the achievement_count of this SummaryActivity.

        The number of achievements gained during this activity  # noqa: E501

        :param achievement_count: The achievement_count of this SummaryActivity.  # noqa: E501
        :type: int
        """

        self._achievement_count = achievement_count

    @property
    def kudos_count(self):
        """Gets the kudos_count of this SummaryActivity.  # noqa: E501

        The number of kudos given for this activity  # noqa: E501

        :return: The kudos_count of this SummaryActivity.  # noqa: E501
        :rtype: int
        """
        return self._kudos_count

    @kudos_count.setter
    def kudos_count(self, kudos_count):
        """Sets the kudos_count of this SummaryActivity.

        The number of kudos given for this activity  # noqa: E501

        :param kudos_count: The kudos_count of this SummaryActivity.  # noqa: E501
        :type: int
        """

        self._kudos_count = kudos_count

    @property
    def comment_count(self):
        """Gets the comment_count of this SummaryActivity.  # noqa: E501

        The number of comments for this activity  # noqa: E501

        :return: The comment_count of this SummaryActivity.  # noqa: E501
        :rtype: int
        """
        return self._comment_count

    @comment_count.setter
    def comment_count(self, comment_count):
        """Sets the comment_count of this SummaryActivity.

        The number of comments for this activity  # noqa: E501

        :param comment_count: The comment_count of this SummaryActivity.  # noqa: E501
        :type: int
        """

        self._comment_count = comment_count

    @property
    def athlete_count(self):
        """Gets the athlete_count of this SummaryActivity.  # noqa: E501

        The number of athletes for taking part in a group activity  # noqa: E501

        :return: The athlete_count of this SummaryActivity.  # noqa: E501
        :rtype: int
        """
        return self._athlete_count

    @athlete_count.setter
    def athlete_count(self, athlete_count):
        """Sets the athlete_count of this SummaryActivity.

        The number of athletes for taking part in a group activity  # noqa: E501

        :param athlete_count: The athlete_count of this SummaryActivity.  # noqa: E501
        :type: int
        """
        if athlete_count is not None and athlete_count < 1:  # noqa: E501
            raise ValueError("Invalid value for `athlete_count`, must be a value greater than or equal to `1`")  # noqa: E501

        self._athlete_count = athlete_count

    @property
    def photo_count(self):
        """Gets the photo_count of this SummaryActivity.  # noqa: E501

        The number of Instagram photos for this activity  # noqa: E501

        :return: The photo_count of this SummaryActivity.  # noqa: E501
        :rtype: int
        """
        return self._photo_count

    @photo_count.setter
    def photo_count(self, photo_count):
        """Sets the photo_count of this SummaryActivity.

        The number of Instagram photos for this activity  # noqa: E501

        :param photo_count: The photo_count of this SummaryActivity.  # noqa: E501
        :type: int
        """

        self._photo_count = photo_count

    @property
    def total_photo_count(self):
        """Gets the total_photo_count of this SummaryActivity.  # noqa: E501

        The number of Instagram and Strava photos for this activity  # noqa: E501

        :return: The total_photo_count of this SummaryActivity.  # noqa: E501
        :rtype: int
        """
        return self._total_photo_count

    @total_photo_count.setter
    def total_photo_count(self, total_photo_count):
        """Sets the total_photo_count of this SummaryActivity.

        The number of Instagram and Strava photos for this activity  # noqa: E501

        :param total_photo_count: The total_photo_count of this SummaryActivity.  # noqa: E501
        :type: int
        """

        self._total_photo_count = total_photo_count

    @property
    def map(self):
        """Gets the map of this SummaryActivity.  # noqa: E501


        :return: The map of this SummaryActivity.  # noqa: E501
        :rtype: PolylineMap
        """
        return self._map

    @map.setter
    def map(self, map):
        """Sets the map of this SummaryActivity.


        :param map: The map of this SummaryActivity.  # noqa: E501
        :type: PolylineMap
        """

        self._map = map

    @property
    def trainer(self):
        """Gets the trainer of this SummaryActivity.  # noqa: E501

        Whether this activity was recorded on a training machine  # noqa: E501

        :return: The trainer of this SummaryActivity.  # noqa: E501
        :rtype: bool
        """
        return self._trainer

    @trainer.setter
    def trainer(self, trainer):
        """Sets the trainer of this SummaryActivity.

        Whether this activity was recorded on a training machine  # noqa: E501

        :param trainer: The trainer of this SummaryActivity.  # noqa: E501
        :type: bool
        """

        self._trainer = trainer

    @property
    def commute(self):
        """Gets the commute of this SummaryActivity.  # noqa: E501

        Whether this activity is a commute  # noqa: E501

        :return: The commute of this SummaryActivity.  # noqa: E501
        :rtype: bool
        """
        return self._commute

    @commute.setter
    def commute(self, commute):
        """Sets the commute of this SummaryActivity.

        Whether this activity is a commute  # noqa: E501

        :param commute: The commute of this SummaryActivity.  # noqa: E501
        :type: bool
        """

        self._commute = commute

    @property
    def manual(self):
        """Gets the manual of this SummaryActivity.  # noqa: E501

        Whether this activity was created manually  # noqa: E501

        :return: The manual of this SummaryActivity.  # noqa: E501
        :rtype: bool
        """
        return self._manual

    @manual.setter
    def manual(self, manual):
        """Sets the manual of this SummaryActivity.

        Whether this activity was created manually  # noqa: E501

        :param manual: The manual of this SummaryActivity.  # noqa: E501
        :type: bool
        """

        self._manual = manual

    @property
    def private(self):
        """Gets the private of this SummaryActivity.  # noqa: E501

        Whether this activity is private  # noqa: E501

        :return: The private of this SummaryActivity.  # noqa: E501
        :rtype: bool
        """
        return self._private

    @private.setter
    def private(self, private):
        """Sets the private of this SummaryActivity.

        Whether this activity is private  # noqa: E501

        :param private: The private of this SummaryActivity.  # noqa: E501
        :type: bool
        """

        self._private = private

    @property
    def flagged(self):
        """Gets the flagged of this SummaryActivity.  # noqa: E501

        Whether this activity is flagged  # noqa: E501

        :return: The flagged of this SummaryActivity.  # noqa: E501
        :rtype: bool
        """
        return self._flagged

    @flagged.setter
    def flagged(self, flagged):
        """Sets the flagged of this SummaryActivity.

        Whether this activity is flagged  # noqa: E501

        :param flagged: The flagged of this SummaryActivity.  # noqa: E501
        :type: bool
        """

        self._flagged = flagged

    @property
    def workout_type(self):
        """Gets the workout_type of this SummaryActivity.  # noqa: E501

        The activity's workout type  # noqa: E501

        :return: The workout_type of this SummaryActivity.  # noqa: E501
        :rtype: int
        """
        return self._workout_type

    @workout_type.setter
    def workout_type(self, workout_type):
        """Sets the workout_type of this SummaryActivity.

        The activity's workout type  # noqa: E501

        :param workout_type: The workout_type of this SummaryActivity.  # noqa: E501
        :type: int
        """

        self._workout_type = workout_type

    @property
    def average_speed(self):
        """Gets the average_speed of this SummaryActivity.  # noqa: E501

        The activity's average speed, in meters per second  # noqa: E501

        :return: The average_speed of this SummaryActivity.  # noqa: E501
        :rtype: float
        """
        return self._average_speed

    @average_speed.setter
    def average_speed(self, average_speed):
        """Sets the average_speed of this SummaryActivity.

        The activity's average speed, in meters per second  # noqa: E501

        :param average_speed: The average_speed of this SummaryActivity.  # noqa: E501
        :type: float
        """

        self._average_speed = average_speed

    @property
    def max_speed(self):
        """Gets the max_speed of this SummaryActivity.  # noqa: E501

        The activity's max speed, in meters per second  # noqa: E501

        :return: The max_speed of this SummaryActivity.  # noqa: E501
        :rtype: float
        """
        return self._max_speed

    @max_speed.setter
    def max_speed(self, max_speed):
        """Sets the max_speed of this SummaryActivity.

        The activity's max speed, in meters per second  # noqa: E501

        :param max_speed: The max_speed of this SummaryActivity.  # noqa: E501
        :type: float
        """

        self._max_speed = max_speed

    @property
    def has_kudoed(self):
        """Gets the has_kudoed of this SummaryActivity.  # noqa: E501

        Whether the logged-in athlete has kudoed this activity  # noqa: E501

        :return: The has_kudoed of this SummaryActivity.  # noqa: E501
        :rtype: bool
        """
        return self._has_kudoed

    @has_kudoed.setter
    def has_kudoed(self, has_kudoed):
        """Sets the has_kudoed of this SummaryActivity.

        Whether the logged-in athlete has kudoed this activity  # noqa: E501

        :param has_kudoed: The has_kudoed of this SummaryActivity.  # noqa: E501
        :type: bool
        """

        self._has_kudoed = has_kudoed

    @property
    def gear_id(self):
        """Gets the gear_id of this SummaryActivity.  # noqa: E501

        The id of the gear for the activity  # noqa: E501

        :return: The gear_id of this SummaryActivity.  # noqa: E501
        :rtype: str
        """
        return self._gear_id

    @gear_id.setter
    def gear_id(self, gear_id):
        """Sets the gear_id of this SummaryActivity.

        The id of the gear for the activity  # noqa: E501

        :param gear_id: The gear_id of this SummaryActivity.  # noqa: E501
        :type: str
        """

        self._gear_id = gear_id

    @property
    def kilojoules(self):
        """Gets the kilojoules of this SummaryActivity.  # noqa: E501

        The total work done in kilojoules during this activity. Rides only  # noqa: E501

        :return: The kilojoules of this SummaryActivity.  # noqa: E501
        :rtype: float
        """
        return self._kilojoules

    @kilojoules.setter
    def kilojoules(self, kilojoules):
        """Sets the kilojoules of this SummaryActivity.

        The total work done in kilojoules during this activity. Rides only  # noqa: E501

        :param kilojoules: The kilojoules of this SummaryActivity.  # noqa: E501
        :type: float
        """

        self._kilojoules = kilojoules

    @property
    def average_watts(self):
        """Gets the average_watts of this SummaryActivity.  # noqa: E501

        Average power output in watts during this activity. Rides only  # noqa: E501

        :return: The average_watts of this SummaryActivity.  # noqa: E501
        :rtype: float
        """
        return self._average_watts

    @average_watts.setter
    def average_watts(self, average_watts):
        """Sets the average_watts of this SummaryActivity.

        Average power output in watts during this activity. Rides only  # noqa: E501

        :param average_watts: The average_watts of this SummaryActivity.  # noqa: E501
        :type: float
        """

        self._average_watts = average_watts

    @property
    def device_watts(self):
        """Gets the device_watts of this SummaryActivity.  # noqa: E501

        Whether the watts are from a power meter, false if estimated  # noqa: E501

        :return: The device_watts of this SummaryActivity.  # noqa: E501
        :rtype: bool
        """
        return self._device_watts

    @device_watts.setter
    def device_watts(self, device_watts):
        """Sets the device_watts of this SummaryActivity.

        Whether the watts are from a power meter, false if estimated  # noqa: E501

        :param device_watts: The device_watts of this SummaryActivity.  # noqa: E501
        :type: bool
        """

        self._device_watts = device_watts

    @property
    def max_watts(self):
        """Gets the max_watts of this SummaryActivity.  # noqa: E501

        Rides with power meter data only  # noqa: E501

        :return: The max_watts of this SummaryActivity.  # noqa: E501
        :rtype: int
        """
        return self._max_watts

    @max_watts.setter
    def max_watts(self, max_watts):
        """Sets the max_watts of this SummaryActivity.

        Rides with power meter data only  # noqa: E501

        :param max_watts: The max_watts of this SummaryActivity.  # noqa: E501
        :type: int
        """

        self._max_watts = max_watts

    @property
    def weighted_average_watts(self):
        """Gets the weighted_average_watts of this SummaryActivity.  # noqa: E501

        Similar to Normalized Power. Rides with power meter data only  # noqa: E501

        :return: The weighted_average_watts of this SummaryActivity.  # noqa: E501
        :rtype: int
        """
        return self._weighted_average_watts

    @weighted_average_watts.setter
    def weighted_average_watts(self, weighted_average_watts):
        """Sets the weighted_average_watts of this SummaryActivity.

        Similar to Normalized Power. Rides with power meter data only  # noqa: E501

        :param weighted_average_watts: The weighted_average_watts of this SummaryActivity.  # noqa: E501
        :type: int
        """

        self._weighted_average_watts = weighted_average_watts

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SummaryActivity, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SummaryActivity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
